Properties Methods Events Direct Link

# Class Ext.ux.menu.RangeMenu

Package: | Ext.ux.menu
Defined In: | RangeMenu.js
Class: | RangeMenu
Extends: | Object

Custom implementation of Ext.menu.Menu that has preconfigured items for gt, lt, eq.

Example Usage:

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| getValue() : String Get and return the value of the filter. Get and return the value of the filter. Parameters: None. Returns: `String` The value of this filter | RangeMenu
| setValue( `Object data` ) : void Set the value of this menu and fires the 'update' event. Set the value of this menu and fires the 'update' event. Parameters: `data` : Object The data to assign to this menu Returns: void | RangeMenu

## Public Events

Event | Defined By
--- | ---
| update : ( `Ext.ux.grid.filter.Filter this` ) Fires when a filter configuration has changed Fires when a filter configuration has changed Listeners will be called with the following arguments: `this` : Ext.ux.grid.filter.Filter The filter object. | RangeMenu
| update : ( `Ext.ux.grid.filter.Filter this` ) Fires when a filter configuration has changed Fires when a filter configuration has changed Listeners will be called with the following arguments: `this` : Ext.ux.grid.filter.Filter The filter object. | RangeMenu